@@ -2,8 +2,7 @@ import pymysql
 from notesecret import read_secret
 from pymysql.cursors import DictCursor
 from sqlalchemy import MetaData, Table, create_engine, delete, inspect, select
-#from sqlalchemy.dialects.mysql import insert
-from sqlalchemy.dialects.postgresql import insert
+from sqlalchemy.dialects.mysql import insert
 
 engine_dict = {}
 meta_dict = {}
@@ -84,5 +83,5 @@ class BaseTable:
         primary_keys = [key.name for key in inspect(self.table).primary_key]
         update_dict = {c.name: c for c in stmt.inserted if
                        not c.primary_key and c.name not in ('gmt_create', 'gmt_modified')}
-        stmt = stmt.on_conflict_do_update(index_elements=primary_keys, set_=update_dict)
+        stmt = stmt.on_duplicate_key_update(update_dict)
         self.engine.execute(stmt)
